<?php

namespace Drupal\parameters_ui;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides dynamic permissions of the Parameters UI module.
 */
class ParametersUiPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new FieldUiPermissions instance.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity_type.manager'));
  }

  /**
   * Returns an array of Parameters UI permissions.
   *
   * @return array
   *   The permissions.
   */
  public function parameterPermissions(): array {
    $permissions = [
      'administer parameters' => [
        'title' => $this->t('Administer all parameters'),
        'description' => $this->t('Create, edit and delete all collections of parameters.'),
        'restrict access' => TRUE,
      ],
      'unlock parameters' => [
        'title' => $this->t('Unlock parameters'),
        'description' => $this->t('Unlock collections of parameters for removal.'),
        'restrict access' => TRUE,
      ],
    ];

    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if (!$entity_type->get('field_ui_base_route')) {
        continue;
      }
      // Create a permission for each fieldable entity.
      $permissions['administer ' . $entity_type_id . ' parameters'] = [
        'title' => $this->t('%entity_label: Administer parameters', ['%entity_label' => $entity_type->getLabel()]),
        'restrict access' => TRUE,
        'dependencies' => ['module' => [$entity_type->getProvider()]],
      ];
    }

    return $permissions;
  }

}
